# Copyright 1999-2024. WebPros International GmbH. All rights reserved.

# Unfortunately, mailman3 postorius does not offer a method to send confirmation
# emails from the virtual domains using request data.
# Therefore, we need to create a subclass of DefaultAccountAdapter from django allauth
# with overridden get_from_email() method, as explained in the allauth source code,
# to ensure that confirmation emails are sent from the correct domain.
# Further information can be found here: https://github.com/pennersr/django-allauth/blob/main/allauth/account/adapter.py#L43-L47

from django.conf import settings
from allauth.account.adapter import DefaultAccountAdapter


class PleskAccountAdapter(DefaultAccountAdapter):
    def get_from_email(self):
        """
        This is a hook to set the 'from' email address for sending emails
        """
        domain = self.request.get_host()
        return f"postorius@{domain}"
